"use strict";
/*---------------------------------------------------------------------------------------------
 * Copyright (c) Bentley Systems, Incorporated. All rights reserved.
 * See LICENSE.md in the project root for license terms and full copyright notice.
 *--------------------------------------------------------------------------------------------*/
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const React = __importStar(require("react"));
const react_dom_1 = __importDefault(require("react-dom"));
const ToastMaster_1 = __importDefault(require("./ToastMaster"));
class Toaster {
    constructor() {
        this.success = this.success.bind(this);
        this.error = this.error.bind(this);
        this.informational = this.informational.bind(this);
        this.notifyHandler = null;
        this.closeAllHandler = null;
        this._bindNotify = this._bindNotify.bind(this);
        this._bindCloseAll = this._bindCloseAll.bind(this);
        const container = document.createElement("div");
        container.setAttribute("itwin-toaster-container", "");
        document.body.appendChild(container);
        react_dom_1.default.render(React.createElement(ToastMaster_1.default, { bindNotify: this._bindNotify, bindCloseAll: this._bindCloseAll }), container);
    }
    /* Call a Toast component with the success category */
    success(text, settings) {
        if (this.notifyHandler) {
            this.notifyHandler({
                category: "success",
                duration: settings && settings.duration ? settings.duration : undefined,
                hasCloseButton: settings && settings.hasCloseButton
                    ? settings.hasCloseButton
                    : undefined,
                link: settings && settings.link ? settings.link : undefined,
                text,
                type: settings && settings.type ? settings.type : "persisting",
            });
        }
    }
    /* Call a Toast component with the informational category */
    informational(text, settings) {
        if (this.notifyHandler) {
            this.notifyHandler({
                category: "informational",
                duration: settings && settings.duration ? settings.duration : undefined,
                hasCloseButton: settings && settings.hasCloseButton
                    ? settings.hasCloseButton
                    : undefined,
                link: settings && settings.link ? settings.link : undefined,
                text,
                type: settings && settings.type ? settings.type : "persisting",
            });
        }
    }
    /* Call a Toast component with the error category */
    error(text, settings) {
        if (this.notifyHandler) {
            this.notifyHandler({
                category: "error",
                duration: settings && settings.duration ? settings.duration : undefined,
                hasCloseButton: settings && settings.hasCloseButton
                    ? settings.hasCloseButton
                    : undefined,
                link: settings && settings.link ? settings.link : undefined,
                text,
                type: settings && settings.type ? settings.type : "persisting",
            });
        }
    }
    /* Call closeAll from ToastManager */
    closeAll() {
        if (this.closeAllHandler) {
            this.closeAllHandler();
        }
    }
    /* Bind the notify function from ToastManager */
    _bindNotify(notify) {
        this.notifyHandler = notify;
    }
    /* Bind the closeAll function from ToastManager */
    _bindCloseAll(closeAll) {
        this.closeAllHandler = closeAll;
    }
}
exports.default = Toaster;
//# sourceMappingURL=Toaster.js.map